//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MindFusion.Gauges;


namespace MindFusion.Gauges.WinForms.Samples.CS.Thermometer
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
		
            g.PrepaintBackground += g_PrepaintBackground;
            g.PrepaintForeground += g_PrepaintForeground;
            g.PrepaintScale += g_PaintScale;
            rightScale = g.Scales[1];
            Setup(g.Scales[0], Alignment.InnerInside);
            
            Setup(rightScale, Alignment.OuterOutside);

            rightScale.MajorTickSettings.LabelOffset = new Length(-12);
            rightScale.Stroke = new MindFusion.Drawing.Pen(Color.White);
            rightScale.Pointers[0].IsInteractive = true;

            quickSilver = new Range();
            quickSilver.MinValue = rightScale.MinValue - 12;
            quickSilver.MaxValue = rightScale.MaxValue;
            quickSilver.Alignment = Alignment.TrueCenter;
            quickSilver.AutoSize = true;
            
            quickSilver.Fill = Utils.LinearGradient(0, 0f, Color.FromArgb(0xff, 0xaa, 0, 0), 0.3f, Color.FromArgb(0xff, 0xff, 0x66, 0x66), 
                0.31f, Color.FromArgb(0x99, Color.White), 0.35f, Color.FromArgb(0xff, 0xff, 0x66, 0x66),
                1f, Color.FromArgb(0xff, 0xaa, 0, 0));
            quickSilver.Stroke = new MindFusion.Drawing.Pen(Color.Transparent);

            rightScale.Ranges.Add(quickSilver);
            rightScale.Pointers[0].ValueChanged += Form1_ValueChanged;
            rightScale.Pointers[0].Value = 50;

            Range termoRange = new Range();
            termoRange.MinValue = 150;
            termoRange.MaxValue = 212;
            termoRange.Alignment = Alignment.OuterOutside;
            termoRange.StartWidth = new Length(0);
            termoRange.EndWidth = new Length(10);
            termoRange.Stroke = new MindFusion.Drawing.Pen(Color.White);
            termoRange.Fill = Utils.LinearGradient(90, 0.25f, Color.Yellow, 0.9f, Color.Red);
            rightScale.Ranges.Add(termoRange);

            ind.Bounds = new RectangleF(-5, 130, 15, 15);
            AddCustomInterval(50, 100, Color.Green);
            AddCustomInterval(100, 150, Color.Yellow);
            AddCustomInterval(150, 212, Color.Red);

            rightScale.ScaleChildren.Add(ind);

            Text t;
            t = new Text();
            t.Margin = new MindFusion.Thickness(0f, 0.9f, 0, 0);
            t.Content = "C";
            t.Foreground = Color.White;
            t.FontSize = new Length(15);
            rightScale.ScaleChildren.Add(t);

            t = new Text();
            t.Margin = new MindFusion.Thickness(0.75f, 0.9f, 0, 0);
            t.Content = "F";
            t.Foreground = Color.White;
            t.FontSize = new Length(15);
            rightScale.ScaleChildren.Add(t);
        }

        LinearScale rightScale;
        Range quickSilver;
        Indicator ind = new Indicator();

        void AddCustomInterval(float min, float max, Color c) {
            CustomInterval ci = new CustomInterval();
            ci.MinValue = min;
            ci.MaxValue = max;
            ci.Stroke = new MindFusion.Drawing.Pen(Color.White);
            ci.Fill = new MindFusion.Drawing.SolidBrush(c);
            ind.States.Add(ci);
        }
        
        void Form1_ValueChanged(object sender, ValueChangedEventArgs<float> e)
        {
            ind.Value = quickSilver.MaxValue = e.NewValue;
        }

        private void Setup(LinearScale s, Alignment tickAlignment)
        {
            s.Left = new Length(50, LengthType.Relative);
            s.Top = new Length(5, LengthType.Relative);
            s.ScaleLength = new Length(80, LengthType.Relative);
            s.Orientation = Orientation.Vertical;
            s.StartWidth = s.EndWidth = new Length(8);
            s.Fill= new MindFusion.Drawing.SolidBrush(Color.Transparent);
            s.Stroke = new MindFusion.Drawing.Pen(Color.White);

            MajorTickSettings mj = s.MajorTickSettings;

            mj.Count = 10;
            mj.TickShape = TickShape.Rectangle;
            mj.TickWidth = new Length(10);
            mj.TickHeight = new Length(1);
            mj.LabelOffset= new Length(12);
            mj.Stroke = new MindFusion.Drawing.Pen(Color.White);
            mj.FontSize = new Length(10, LengthType.Relative);
            mj.FontStyle = FontStyle.Regular;
            mj.LabelForeground = Color.White;

            MiddleTickSettings md = s.MiddleTickSettings;
            md.Count= 5;
            md.ShowLabels = false;
            md.ShowTicks = true;
            md.TickShape = TickShape.Rectangle;
            md.TickWidth = new Length(4);
            md.TickHeight = new Length(1);
            md.Stroke = mj.Stroke;

            mj.LabelAlignment = mj.TickAlignment = md.TickAlignment = tickAlignment;
            
            s.MinorTickSettings.ShowTicks = false;
        }

        void g_PaintScale(object sender, CustomPaintEventArgs e)
        {
            Ellipse el = new Ellipse();
            el.Margin = new MindFusion.Thickness(0.35f, 0.9f, 0.35f, 0.01f, true);
            el.Fill = Utils.RadialGradient(0f, Color.FromArgb(0xff, 0x99, 0, 0), 1f, Color.FromArgb(0xff, 0xFF, 0x66, 0x66));
            el.Stroke = new MindFusion.Drawing.Pen(Color.White);
            e.PaintVisualElement(el, e.Element.RenderSize);
        }

        void g_PrepaintForeground(object sender, MindFusion.Gauges.PrepaintEventArgs e)
        {
            e.CancelDefaultPainting = true;
            RoundRectangle r = new RoundRectangle();
            r.Roundness = 20;
            r.Fill = Utils.LinearGradient(45, 0.2f, Color.FromArgb(0x30, Color.White), 0.6f, Color.Transparent);
            e.PaintVisualElement(r, e.Element.RenderSize);
        }

        void g_PrepaintBackground(object sender, MindFusion.Gauges.PrepaintEventArgs e)
        {
            e.CancelDefaultPainting = true;
            RoundRectangle r = new RoundRectangle();
            r.Roundness = 20;
            r.Margin = new MindFusion.Thickness(0, 0, 3, 3, false);
            r.Stroke = new MindFusion.Drawing.Pen(Color.FromArgb(0x30, Color.White), 1);
            r.Fill = Utils.LinearGradient(45, 0f, Utils.Gray(0x9a), 0.6f, Utils.Gray(0x21));
            e.PaintVisualElement(r, e.Element.RenderSize);

            RoundRectangle r2 = new RoundRectangle();
            r2.Roundness = 20;
            r2.Stroke = new MindFusion.Drawing.Pen(Utils.Gray(0x7a), 2);
            e.PaintVisualElement(r2, e.Element.RenderSize);
        }
    }
}